@@ -6,7 +6,9 @@ from typing import TYPE_CHECKING, Any, Callable, ClassVar
 import dask.dataframe as dd
 
 from narwhals._compliant import DepthTrackingGroupBy
+from narwhals._dask.utils import make_group_by_kwargs
 from narwhals._expression_parsing import evaluate_output_names_and_aliases
+from narwhals._utils import zip_strict
 
 if TYPE_CHECKING:
     from collections.abc import Mapping, Sequence
@@ -16,7 +18,7 @@ if TYPE_CHECKING:
     from pandas.core.groupby import SeriesGroupBy as _PandasSeriesGroupBy
     from typing_extensions import TypeAlias
 
-    from narwhals._compliant.group_by import NarwhalsAggregation
+    from narwhals._compliant.typing import NarwhalsAggregation
     from narwhals._dask.dataframe import DaskLazyFrame
     from narwhals._dask.expr import DaskExpr
 
@@ -26,7 +28,7 @@ if TYPE_CHECKING:
 else:
     try:
         import dask.dataframe.dask_expr as dx
-    except ModuleNotFoundError:  # pragma: no cover
+    except ModuleNotFoundError:
         import dask_expr as dx
     _DaskGroupBy = dx._groupby.GroupBy
 
@@ -44,6 +46,26 @@ def n_unique() -> dd.Aggregation:
     return dd.Aggregation(name="nunique", chunk=chunk, agg=agg)
 
 
+def _all() -> dd.Aggregation:
+    def chunk(s: PandasSeriesGroupBy) -> pd.Series[Any]:
+        return s.all(skipna=True)
+
+    def agg(s0: PandasSeriesGroupBy) -> pd.Series[Any]:
+        return s0.all(skipna=True)
+
+    return dd.Aggregation(name="all", chunk=chunk, agg=agg)
+
+
+def _any() -> dd.Aggregation:
+    def chunk(s: PandasSeriesGroupBy) -> pd.Series[Any]:
+        return s.any(skipna=True)
+
+    def agg(s0: PandasSeriesGroupBy) -> pd.Series[Any]:
+        return s0.any(skipna=True)
+
+    return dd.Aggregation(name="any", chunk=chunk, agg=agg)
+
+
 def var(ddof: int) -> _AggFn:
     return partial(_DaskGroupBy.var, ddof=ddof)
 
@@ -64,6 +86,9 @@ class DaskLazyGroupBy(DepthTrackingGroupBy["DaskLazyFrame", "DaskExpr", Aggregat
         "len": "size",
         "n_unique": n_unique,
         "count": "count",
+        "quantile": "quantile",
+        "all": _all,
+        "any": _any,
     }
 
     def __init__(
@@ -77,9 +102,8 @@ class DaskLazyGroupBy(DepthTrackingGroupBy["DaskLazyFrame", "DaskExpr", Aggregat
         self._compliant_frame, self._keys, self._output_key_names = self._parse_keys(
             df, keys=keys
         )
-        self._grouped = self.compliant.native.groupby(
-            self._keys, dropna=drop_null_keys, observed=True
-        )
+        group_by_kwargs = make_group_by_kwargs(drop_null_keys=drop_null_keys)
+        self._grouped = self.compliant.native.groupby(self._keys, **group_by_kwargs)
 
     def agg(self, *exprs: DaskExpr) -> DaskLazyFrame:
         from narwhals._dask.dataframe import DaskLazyFrame
@@ -88,7 +112,7 @@ class DaskLazyGroupBy(DepthTrackingGroupBy["DaskLazyFrame", "DaskExpr", Aggregat
             # No aggregation provided
             return (
                 self.compliant.simple_select(*self._keys)
-                .unique(self._keys, keep="any")
+                .unique(self._keys, keep="any", order_by=None)
                 .rename(dict(zip(self._keys, self._output_key_names)))
             )
 
@@ -102,23 +126,23 @@ class DaskLazyGroupBy(DepthTrackingGroupBy["DaskLazyFrame", "DaskExpr", Aggregat
             output_names, aliases = evaluate_output_names_and_aliases(
                 expr, self.compliant, exclude
             )
-            if expr._depth == 0:
+            last_node = next(expr._metadata.op_nodes_reversed())
+            if len(list(expr._metadata.op_nodes_reversed())) == 1:
                 # e.g. `agg(nw.len())`
                 column = self._keys[0]
-                agg_fn = self._remap_expr_name(expr._function_name)
+                agg_fn = self._remap_expr_name(last_node.name)
                 simple_aggregations.update(dict.fromkeys(aliases, (column, agg_fn)))
                 continue
 
             # e.g. `agg(nw.mean('a'))`
             agg_fn = self._remap_expr_name(self._leaf_name(expr))
             # deal with n_unique case in a "lazy" mode to not depend on dask globally
-            agg_fn = agg_fn(**expr._scalar_kwargs) if callable(agg_fn) else agg_fn
+            agg_fn = agg_fn(**last_node.kwargs) if callable(agg_fn) else agg_fn
             simple_aggregations.update(
                 (alias, (output_name, agg_fn))
-                for alias, output_name in zip(aliases, output_names)
+                for alias, output_name in zip_strict(aliases, output_names)
             )
         return DaskLazyFrame(
             self._grouped.agg(**simple_aggregations).reset_index(),
-            backend_version=self.compliant._backend_version,
             version=self.compliant._version,
         ).rename(dict(zip(self._keys, self._output_key_names)))
