@@ -27,6 +27,8 @@ if TYPE_CHECKING:
 def test_to_native(
     constructor_eager: ConstructorEager, method: str, *, pass_through: bool, context: Any
 ) -> None:
+    if method == "to_numpy":
+        pytest.importorskip("mumpy")
     df = nw.from_native(constructor_eager({"a": [1, 2, 3]}))
 
     with context:
